<?php

include_once('configure.AccountMedpass.php'); 	// pliki konfiguracyjne medpass
include_once('class.openid.php');				// klasa do obslugi openid

/**
 * class AccountMedpass
 * Przykladowa klasa oblsugujaca logowanie Medpass 2.0
 *
 */

class AccountMedpass {
	
	/**
	 * Metoda sprawdza, czy uzytkownik jest zalogowany
	 * obsluguje jednoczesnie wylogowywanie
	 *
	 * @return boolean lub przekierowanie na strone ustawiona w pliku konfiguracyjnym
	 */
	function isLogged(){		
		
		// sprawdzamy, czy uzytkonik nie chce sie wylogowac
		if ($_GET[MEDPASS_ACTION_LOGOUT]==1){			
			$_SESSION[MEDPASS_SESSION_RETURN_URL] = MEDPASS_RETURN_LOGOUT;
			$this->logout();			
		}
		
		// sprawdzamy, czy uzytkownik jest zalogowany 
		// lub czy proces logowania prebiegl poprawnie
		if (!$_SESSION[MEDPASS_SESSION_LOGGED]==true){						
			if($_POST || $_GET['openid_mode'] == 'id_res'){
				// czyscimy zmienna sesyjna zawerajaca informacje o bledzie
				unset($_SESSION[MEDPASS_ERROR]);
				
				//proba  zalogowania									
				$this->login();				
				// tak naprawde tu nic nie zwracamy bo po logowaniu jestesmy przekierowywani
				// przez metode login do strony ustawionej w pliku konfiguracyjnym
				//return true;
			} else {				
				// niezalogowany
				return false;
			}
		} else {
			// czyscimy zmienna sesyjna zawerajaca informacje o bledzie
			unset($_SESSION[MEDPASS_ERROR]);
			return true;
		}
	}
	
	function login() {		
		// przygotowujemy $loginname - czyli adres na ktory bedziemy sie logowac
		$login = $this->prepare_login($_POST['openid_url']);
		if($login) {
			$this->openidlogin($login);
		} else {			
			// BLAD: nie podano loginu
			$_SESSION[MEDPASS_ERROR] = MEDPASS_ERROR_NO_LOGINNAME;
		}
		$this->redirect_back();
	}
	
	function logout() {			
		unset($_SESSION[MEDPASS_SESSION_LOGGED]);		
		$this->redirect_back();
	}


	function prepare_login($name) {
		$name = strtolower($name);	    
	    $login = 'http://'.$name.'.'.MEDPASS_HOST.'/';	
		return $login;
	}

	function openidlogin($login_url = null, $policyUrl = MEDPASS_POLICY_URL) {    	

		if (@$_POST['openid_action'] == "login"){ 			
			// pobieramy login uzytkownika i przekierowujemy przegladarke na serwer Medpass
			$openid = new SimpleOpenID;			
			$openid->SetIdentity($login_url);			
			$openid->SetTrustRoot('http://' . $_SERVER["HTTP_HOST"]);			
			$openid->SetPolicyUrl(MEDPASS_POLICY_URL);
			$openid->SetApprovedURL(MEDPASS_RETURN_LOGIN);
			$_SESSION[MEDPASS_SESSION_RETURN_URL] = MEDPASS_RETURN_LOGIN;
			
			if ($openid->GetOpenIDServer()){
				// otrzymalismy odpowiedz z serwera Medpass	wiec przekierowujemy uzytkownika na ten serwer				
				$openid->Redirect(); 					
			}else{
				// bledny login - nie ma takiego loginu w medpass 
				// (lub zle skonfigurowany adres serwera medpass)
				$_SESSION[MEDPASS_ERROR] = MEDPASS_ERROR_LOGINNAME;				
		        $this->redirect_back();				
			}
			exit;
		}
		else if(@$_GET['openid_mode'] == 'id_res'){			
			// sprawdzamy, czy w odpowiedzi z serwera otrzymalismy informacje o poprawnym logowaniu
			$openid = new SimpleOpenID;
			$openid->SetIdentity($_GET['openid_identity']);			
			$openid_validation_result = $openid->ValidateWithServer();
			
			if ($openid_validation_result == true){ 	
				// logowanie poprawne
        		$_SESSION[MEDPASS_SESSION_LOGGED] = true;        		        		        		
			}else if($openid->IsError() == true){		
				// otrzymujemy blad serwera Medpass
				$_SESSION[MEDPASS_ERROR] = MEDPASS_ERROR_SERVER;
			} else {				
				// blad autoryzacji
				$_SESSION[MEDPASS_ERROR] = MEDPASS_ERROR_LOGINNAME;
			}			
		}else if ($_GET['openid_mode'] == 'cancel'){ // User Canceled your Request			
			// akcja anulowana przez uzytkownika
			$_SESSION[MEDPASS_ERROR] = MEDPASS_ERROR_USER_CANCEL;
		}		
		$this->redirect_back();	
	}


	function redirect_back( $where = null ) {
			
		if($where) 
			$redirect_to = $where;
		else {
    		if($_SESSION[MEDPASS_SESSION_RETURN_URL])
		  		$redirect_to = $_SESSION[MEDPASS_SESSION_RETURN_URL];
      		else
        		$redirect_to = MEDPASS_RETURN;     
		}				
		header('Location: '.$redirect_to);
	}	
}
?>